class V1::ActivitiesController < ApplicationController
  before_action :authenticate_user!, only: [:my_activities]

  # GET v1/activities
  # GET v1/activities.json
  def index
    render json: PublicActivity::Activity.includes(:owner).order('created_at DESC').all
  end

  # GET v1/activities/my_activities
  # GET v1/activities/my_activities.json
  def my_activities
    render json: activities(current_user)
  end

  # GET v1/activities/object_activities?object_class=LearningObject&object_id=1243
  # GET v1/activities/object_activities.json?object_class=LearningObject&object_id=1243
  def object_activities
    model = object_class params[:object_class]
    render json: activities(model)
  end

  private

  def object_class(object)
    object.constantize if ['User', 'LearningObject', 'Collection', 'Institution'].include? object
  end

  def activities(object)
    condition = '(owner_type = :type AND owner_id = :id) OR (recipient_type = :type AND recipient_id = :id)'
    PublicActivity::Activity.order('created_at DESC').where(condition, {type: object.class.to_s, id: object.id}).all
  end
end
